@@ -1,29 +1,15 @@
-no strict; no warnings;
+use strict; use warnings;
 
 package Text::Tabs;
 
-require Exporter;
+BEGIN { require Exporter; *import = \&Exporter::import }
 
-@ISA = (Exporter);
-@EXPORT = qw(expand unexpand $tabstop);
+our @EXPORT = qw( expand unexpand $tabstop );
 
-use vars qw($VERSION $SUBVERSION $tabstop $debug);
-$VERSION = '2021.0717';
-$SUBVERSION = 'modern';
+our $VERSION = '2021.0726';
+our $SUBVERSION = 'modern'; # back-compat vestige
 
-use strict;
-
-use 5.010_000;
-
-BEGIN	{
-	$tabstop = 8;
-	$debug = 0;
-}
-
-my $CHUNK = qr/\X/;
-
-sub _xlen (_) { scalar(() = $_[0] =~ /$CHUNK/g) } 
-sub _xpos (_) { _xlen( substr( $_[0], 0, pos($_[0]) ) ) }
+our $tabstop = 8;
 
 sub expand {
 	my @l;
@@ -31,16 +17,15 @@ sub expand {
 	for ( @_ ) {
 		my $s = '';
 		for (split(/^/m, $_, -1)) {
-			my $offs = 0;
-			s{\t}{
-			    # this works on both 5.10 and 5.11
-				$pad = $tabstop - (_xlen(${^PREMATCH}) + $offs) % $tabstop;
-			    # this works on 5.11, but fails on 5.10
-				#XXX# $pad = $tabstop - (_xpos() + $offs) % $tabstop;
-				$offs += $pad - 1;
-				" " x $pad;
-			}peg;
-			$s .= $_;
+			my $offs;
+			for (split(/\t/, $_, -1)) {
+				if (defined $offs) {
+					$pad = $tabstop - $offs % $tabstop;
+					$s .= " " x $pad;
+				}
+				$s .= $_;
+				$offs = () = /\PM/g;
+			}
 		}
 		push(@l, $s);
 	}
@@ -61,18 +46,13 @@ sub unexpand
 		@lines = split("\n", $x, -1);
 		for $line (@lines) {
 			$line = expand($line);
-			@e = split(/(${CHUNK}{$tabstop})/,$line,-1);
+			@e = split(/((?:\PM\pM*){$tabstop})/,$line,-1);
 			$lastbit = pop(@e);
 			$lastbit = '' 
 				unless defined $lastbit;
 			$lastbit = "\t"
 				if $lastbit eq $ts_as_space;
 			for $_ (@e) {
-				if ($debug) {
-					my $x = $_;
-					$x =~ s/\t/^I\t/gs;
-					print "sub on '$x'\n";
-				}
 				s/  +$/\t/;
 			}
 			$line = join('',@e, $lastbit);
@@ -84,23 +64,9 @@ sub unexpand
 }
 
 1;
+
 __END__
 
-sub expand
-{
-	my (@l) = @_;
-	for $_ (@l) {
-		1 while s/(^|\n)([^\t\n]*)(\t+)/
-			$1. $2 . (" " x 
-				($tabstop * length($3)
-				- (length($2) % $tabstop)))
-			/sex;
-	}
-	return @l if wantarray;
-	return $l[0];
-}
-
-
 =head1 NAME
 
 Text::Tabs - expand and unexpand tabs like unix expand(1) and unexpand(1)
@@ -166,17 +132,6 @@ Instead of the shell's C<unexpand -a> command, use:
 
   perl -MText::Tabs -n -e 'print unexpand $_'
 
-=head1 SUBVERSION
-
-This module comes in two flavors: one for modern perls (5.10 and above)
-and one for ancient obsolete perls.  The version for modern perls has
-support for Unicode.  The version for old perls does not.  You can tell
-which version you have installed by looking at C<$Text::Tabs::SUBVERSION>:
-it is C<old> for obsolete perls and C<modern> for current perls.
-
-This man page is for the version for modern perls and so that's probably
-what you've got.
-
 =head1 BUGS
 
 Text::Tabs handles only tabs (C<"\t">) and combining characters (C</\pM/>).  It doesn't
